@@ -24,7 +24,7 @@ require Exporter;
         trig      => [ qw/sind cosd tand asind acosd atand atan2d equal/ ],
         );
 
-$VERSION =  '0.95';
+$VERSION =  '0.96';
 $RADEG   = ( 180 / pi );
 $DEGRAD  = ( pi / 180 );
 my $INV360     = ( 1.0 / 360.0 );
@@ -67,6 +67,8 @@ sub sunrise  {
 
     my $tmp_rise_2 = 9;
     my $tmp_rise_3 = 0;
+
+    my $counter = 0;
     until (equal($tmp_rise_2, $tmp_rise_3, 8) )   {
 
        my $d_sunrise_1 = $d + $tmp_rise_1/24.0;
@@ -76,11 +78,13 @@ sub sunrise  {
        ($tmp_rise_3, undef) = sun_rise_set($d_sunrise_2, $lon, $lat, $altit, 15.04107, $arg{upper_limb}, $arg{polar});
 
        #print "tmp_rise2 is: $tmp_rise_2 tmp_rise_3 is:$tmp_rise_3\n";
+       last if ++$counter >= 100;
     }
 
     my $tmp_set_2 = 9;
     my $tmp_set_3 = 0;
 
+    $counter = 0;
     until (equal($tmp_set_2, $tmp_set_3, 8) )   {
 
        my $d_sunset_1 = $d + $tmp_set_1/24.0;
@@ -90,6 +94,7 @@ sub sunrise  {
        (undef, $tmp_set_3) = sun_rise_set($d_sunset_2, $lon, $lat, $altit, 15.04107, $arg{upper_limb}, $arg{polar});
 
        #print "tmp_set_1 is: $tmp_set_1 tmp_set_3 is:$tmp_set_3\n";
+       last if ++$counter >= 100;
 
     }
 
@@ -561,7 +566,7 @@ Astro::Sunrise - Perl extension for computing the sunrise/sunset on a given day
 
 =head1 VERSION
 
-This documentation refers to C<Astro::Sunrise> version 0.95.
+This documentation refers to C<Astro::Sunrise> version 0.96.
 
 =head1 SYNOPSIS
 
@@ -993,6 +998,9 @@ Brian D Foy for providing patch for constants :)
 
 Gabor Szabo for pointing POD mistakes.
 
+People at L<http://geocoder.opencagedata.com/> for noticing an endless
+loop condition and for fixing it.
+
 =head1 CREDITS
 
 =over 4
